#include <Servo.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_MPU6050.h>

Servo pitch;
Servo roll;

const int pitch_pin = 10;
const int roll_pin = 9;

Adafruit_MPU6050 mpu;



void setup() {
  Serial.begin(9600);
  Serial.println("started");
  
  if (!mpu.begin()) {
    Serial.println("Failed to find MPU6050 chip");
    while (1) {
      delay(10);
    }
  }
  
  Serial.println("started MPU");
  mpu.setAccelerometerRange(MPU6050_RANGE_8_G);
  mpu.setGyroRange(MPU6050_RANGE_500_DEG);
  mpu.setFilterBandwidth(MPU6050_BAND_21_HZ);

  setup_servos();
  
}


void loop() {
  /* Get new sensor events with the readings */
  sensors_event_t a, g, temp;
  mpu.getEvent(&a, &g, &temp);
  
  float x_raw = a.acceleration.x;
  float y_raw = a.acceleration.y;
  float z_raw = a.acceleration.z;
  
  float total_acceleration = sqrt(sq(x_raw) + sq(y_raw) + sq(z_raw));


  float x_norm = x_raw / total_acceleration;
  float y_norm = y_raw / total_acceleration;
  float z_norm = z_raw / total_acceleration;

  /*Serial.print("x: ");
  Serial.print(x_norm);
  Serial.print(", y:");
  Serial.print(y_norm);
  Serial.print(", ");
  Serial.print(z_norm);
*/
  int pitch_out = lerp(z_norm, -1, 1, 0, 180);
  int roll_out = lerp(y_norm, -1, 1, 0, 180);
  
  pitch.write(pitch_out);
  roll.write(roll_out);
  delay(1);
  
}

float lerp(float x, float x_0, float x_1, float y_0, float y_1) {
  float first = y_0 * (x_1 - x);
  float second = y_1 * (x - x_0);
  float denominator = x_1 - x_0;

  return (first + second) / denominator;
}

void setup_servos() {
  pitch.attach(pitch_pin);
  roll.attach(roll_pin);

  pitch.write(0);
  roll.write(0);
}
